cadcutils
=========

.. image:: https://img.shields.io/pypi/v/cadcutils.svg   
    :target: https://pypi.python.org/pypi/cadcutils

Canadian Astronomy Data Centre Python Utilities

General CADC Python library
